Patch for getstream to be able to stream more channels than it would otherwise.
(works with getstream-20060711 from http://silicon-verl.de/home/flo/projects/streaming/)
 -- Tomas Janousek, <tomi@nomi.cz>

diff -aur getstream-20060711.orig/demux.c getstream-20060711/demux.c
--- getstream-20060711.orig/demux.c	2006-07-11 21:54:50.000000000 +0200
+++ getstream-20060711/demux.c	2006-08-29 00:53:11.000000000 +0200
@@ -386,6 +386,11 @@
 }
 
 static void pmt_join_pid(struct channel_s *channel, int pid, int pidtype) {
+	/* My adapter does not have enough pid filters to receive more than
+	 * A+V. */
+	if (pidtype != PID_VIDEO && pidtype != PID_AUDIO)
+		return;
+
 	/* Do we already receive this pid ? */
 	if (channel->pidtable[pid].type == PID_NONE) {
 
@@ -607,6 +612,12 @@
 
 				switch(c->pidtable[pid].type) {
 					case(PID_PMT):
+						/* We have to close PMT pid to
+						 * make room for other
+						 * channels. */
+						dmx_leave_pid(c->adapter, pid);
+						c->pidtable[pid].type = PID_NONE;
+
 						pmt_process(c, &db[i]);
 						stream_send(c, &db[i]);
 						break;
@@ -838,6 +849,10 @@
 
 				/* Append to adapter pidtable */
 				if (channel->pidtable[ppid].type == PID_NONE) {
+					/* We have opened this before and we
+					 * don't want to do it again. */
+					if (channel->pmtpid == ppid)
+						break;
 
 					if (!adapter->pidtable[ppid])
 						dmx_join_pid(adapter, ppid);
@@ -998,8 +1013,9 @@
 	tv.tv_usec=0;
 	tv.tv_sec=5;
 
-	evtimer_set(&peevent, pidexpire, adapter);
-	evtimer_add(&peevent, &tv);
+	/* No expiring since we won't get any refreshes. */
+	/*evtimer_set(&peevent, pidexpire, adapter);
+	evtimer_add(&peevent, &tv);*/
 }
 
 
diff -aur getstream-20060711.orig/stream_http.c getstream-20060711/stream_http.c
--- getstream-20060711.orig/stream_http.c	2006-06-23 23:46:57.000000000 +0200
+++ getstream-20060711/stream_http.c	2006-08-29 13:39:39.000000000 +0200
@@ -46,7 +46,7 @@
 			hc->arg=hr;
 
 			/* Return head */
-			http_header_start(hc, "200 OK", "application/octet-stream");
+			http_header_start(hc, "200 OK", "video/mpeg");
 			http_header_nocache(hc);
 			http_header_clength(hc, -1);
 			http_header_end(hc);
